==> streamtuner-0.11.0.tar.gz: streamtuner-0.11.0/src/sgtk/sgtk-dialog.h <==
/*
 * $Id: sgtk-dialog.h,v 1.8 2004/01/05 19:44:09 jylefort Exp $
 *
 * Copyright (c) 2002, 2003 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _SGTK_DIALOG_H
#define _SGTK_DIALOG_H

#include <gtk/gtk.h>

#define SGTK_TYPE_DIALOG		(sgtk_dialog_get_type())
#define SGTK_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), SGTK_TYPE_DIALOG, sGtkDialog))
#define SGTK_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), SGTK_TYPE_DIALOG, sGtkDialogClass))
#define SGTK_IS_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), SGTK_TYPE_DIALOG))
#define SGTK_IS_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), SGTK_TYPE_DIALOG))
#define SGTK_DIALOG_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), SGTK_TYPE_DIALOG, sGtkDialogClass))

typedef struct
{
  GtkDialog		dialog;

  GtkWidget		*contents;	/* public */
} sGtkDialog;

typedef struct
{
  GtkDialogClass	parent_class;
} sGtkDialogClass;

GType		sgtk_dialog_get_type		(void);

int		sgtk_dialog_run_from_thread	(GtkDialog *dialog);

#endif /* _SGTK_DIALOG_H */

==> streamtuner_0.12.1.orig.tar.gz: streamtuner-0.12.1/src/sgtk/sgtk-dialog.h <==
/*
 * $Id: sgtk-dialog.h,v 1.10 2004/03/08 05:55:30 jylefort Exp $
 *
 * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _SGTK_DIALOG_H
#define _SGTK_DIALOG_H

#include <gtk/gtk.h>

#define SGTK_TYPE_DIALOG		(sgtk_dialog_get_type())
#define SGTK_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), SGTK_TYPE_DIALOG, sGtkDialog))
#define SGTK_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), SGTK_TYPE_DIALOG, sGtkDialogClass))
#define SGTK_IS_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), SGTK_TYPE_DIALOG))
#define SGTK_IS_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), SGTK_TYPE_DIALOG))
#define SGTK_DIALOG_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), SGTK_TYPE_DIALOG, sGtkDialogClass))

typedef struct
{
  GtkDialog		dialog;

  GtkWidget		*contents;
} sGtkDialog;

typedef struct
{
  GtkDialogClass	parent_class;
} sGtkDialogClass;

GType		sgtk_dialog_get_type		(void);

#endif /* _SGTK_DIALOG_H */
